#include <stdio.h>
#include "target_mlobjs_c.h"

void c_write_string(char *string)
{
	printf("%s", string);
}
